@@ -8,7 +8,7 @@ from pathlib import Path
 import sys
 sys.path.append( '../../../' )
 from src.comm.docker_ver import *
-path_home = '/localpath/' if docker_ver() else str(Path.home())
+path_home = os.getenv('LCP_DKR')+'/' if docker_ver() else str(Path.home())
 
 class GCSBucket(object):
 	"""docstring for Storage"""
@@ -16,8 +16,6 @@ class GCSBucket(object):
 		# self = Cloud().__init__()
 		self.type = "gcs"
 		self.dataset = ""
-		self.raw_location = ""
-		self.prefix_ignore = ''
 		self.BUCKET_NAME = BUCKET_NAME
 		self.credentials = {}
 		self.client = None
@@ -52,18 +50,9 @@ class GCSBucket(object):
 			self.bucket = self.client.get_bucket(self.BUCKET_NAME)
 		else:			
 			if verbose:
+				print('could not find your desired bucket')
 				print('connection failed')
 				raise Exception('Could not find your desired bucket')
-			# print('Do you want to creat a bucket with the name '+self.BUCKET_NAME+"?")
-			# yn = input("[Y/n]: ")
-			# if yn == "y" or yn == "Y":
-			# 	self.bucket = self.client.create_bucket(self.BUCKET_NAME)
-			# else:
-			# 	print('pick another bucket from this list:')
-			# 	for bucket in buckets:
-			# 		print("-" + bucket.name)
-			# 	self.BUCKET_NAME = input("Enter another bucket name: ")
-			# 	return self.connectBucket()
 		return True
 
 	def connect_bucket_api(self,binary):
