@@ -19,12 +19,14 @@ app.add_middleware(
 )
 
 from src.comm.docker_ver import *
-path_home = '/localpath/' if docker_ver() else str(Path.home())
+import os
+path_home = os.getenv('LCP_DKR')+'/' if docker_ver() else str(Path.home())
 
 # checks if local files are installed
 try:
     api = api_core.API()
     initialized = api.start_check()
+    print('commiting')
     api.commit('',False)
 except:
     print('no config file')
@@ -37,14 +39,22 @@ except:
 # End-points
 @app.post("/init_web/")
 async def init_web(data: dict):
-    api.init(data['uri'])
-    api.connect_post_web(data['name'], data)
-    api.start_check()
-    json_compatible_item_data = jsonable_encoder(True)
-    return JSONResponse(content=json_compatible_item_data)
-    # except:
-    #     json_compatible_item_data = jsonable_encoder(False)
-    #     return JSONResponse(content=json_compatible_item_data)
+    try:
+        api.init(data['uri'])
+        api.connect_post_web(data['name'], data)
+        api.start_check()
+        return {'success': True}
+    except:
+        return {'success': False}
+
+@app.get("/connect/")
+async def connect(uri):
+    try:
+        api.init(uri)
+        api.connect_post_api()
+        return {'success': True}
+    except:
+        return {'success': False}
 
 @app.post("/init_gskey/")
 async def init_gskey(file: UploadFile = File(description="A file read as UploadFile")):
@@ -115,10 +125,10 @@ async def key_versions_api(key='',l=5, page=0):
 
 @app.get("/last_n_commits")
 async def last_n_commits_api(n=5):
-    # try:
-    return api.lastNcommits(n)
-    # except:
-    #     return {}
+    try:
+        return api.lastNcommits(n)
+    except:
+        return {}
 
 @app.get("/last_commits_from_hist_api")
 async def last_commits_from_hist_api(n=1):
@@ -152,6 +162,22 @@ async def pull_file_api(file, version='current'):
     except:
         return Response(content='')
 
+@app.get("/pull_csv_api")
+async def pull_csv_api(file, row_p=0, col_p=0, version='current'):
+    try:
+        data, _, _ = api.load_csv_binary(file, row_p, col_p, version)
+        return StreamingResponse(data, media_type="image/png")
+    except:
+        return Response(content='')
+
+@app.get("/pull_csv_metadata_api")
+async def pull_csv_metadata_api(file, version='current'):
+    try:
+        _, nr, nc = api.load_csv_binary(file, 0, 0, version)
+        return {'rows': nr-1, 'cols': nc-1}
+    except:
+        return {'rows': 0, 'cols': 0}
+
 @app.get("/remove_key")
 async def remove_key_api(key):
     try:
